package Bundle::Math::Fractal;
use strict;
use warnings;

$VERSION = '1.00';

1;

__END__

=head1 NAME

Bundle::Math::Fractal - Bundle of modules related to fractals

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Math::Fractal'

=head1 CONTENTS

Math::Fractal::Curve

Math::Fractal::DLA

Math::Fractal::Mandelbrot

=head1 DESCRIPTION

This is a bundle of modules related to fractals.

Please have a look at L<Bundle::Math>.

If you would like to see a specific module included in a future version of
this bundle, please send me an email or use rt.cpan.org.

=head1 AUTHOR

Steffen Mueller E<lt>bundlemath-module at steffen-mueller dot netE<gt>

=cut 
